@@ -32,7 +32,7 @@
 
 #include <QColor>
 
-#include <OGRE/OgreColourValue.h>
+#include <OgreColourValue.h>
 
 #include <rviz/properties/bool_property.h>
 
