@@ -29,7 +29,7 @@
 
 #include <stdint.h>
 
-#include <boost/bind.hpp>
+#include <boost/bind/bind.hpp>
 
 #include <OgreSceneNode.h>
 #include <OgreSceneManager.h>
