@@ -29,9 +29,9 @@
 
 #include <QColor>
 
-#include <OGRE/OgreSceneManager.h>
-#include <OGRE/OgreSceneNode.h>
-#include <OGRE/OgreWireBoundingBox.h>
+#include <OgreSceneManager.h>
+#include <OgreSceneNode.h>
+#include <OgreWireBoundingBox.h>
 
 #include <ros/time.h>
 
@@ -380,6 +380,9 @@ void PointCloudCommon::initialize(DisplayContext* context, Ogre::SceneNode* scen
 
 PointCloudCommon::~PointCloudCommon()
 {
+  // Ensure any threads holding the mutexes have finished
+  boost::recursive_mutex::scoped_lock lock1(transformers_mutex_);
+  boost::mutex::scoped_lock lock2(new_clouds_mutex_);
   delete transformer_class_loader_;
 }
 
