@@ -111,7 +111,7 @@ public:
 
     tf_filter_->connectInput(sub_);
     tf_filter_->registerCallback(
-        boost::bind(&MessageFilterDisplay<MessageType>::incomingMessage, this, _1));
+        boost::bind(&MessageFilterDisplay<MessageType>::incomingMessage, this, boost::placeholders::_1));
     context_->getFrameManager()->registerFilterForTransformStatusCheck(tf_filter_, this);
   }
 
@@ -213,6 +213,9 @@ protected:
 
   void processTypeErasedMessage(boost::shared_ptr<const void> type_erased_msg) override
   {
+    if (!isEnabled())
+      return;
+
     auto msg = boost::static_pointer_cast<const MessageType>(type_erased_msg);
     ++messages_received_;
     setStatus(StatusProperty::Ok, "Topic", QString::number(messages_received_) + " messages received");
