@@ -28,6 +28,7 @@
  */
 
 #include <fstream>
+#include <memory>
 
 #include <QAction>
 #include <QShortcut>
@@ -52,7 +53,7 @@
 
 #include <boost/algorithm/string/split.hpp>
 #include <boost/algorithm/string/trim.hpp>
-#include <boost/bind.hpp>
+#include <boost/bind/bind.hpp>
 #include <boost/filesystem.hpp>
 
 #include <ros/console.h>
@@ -155,15 +156,12 @@ VisualizationFrame::VisualizationFrame(QWidget* parent)
 
 VisualizationFrame::~VisualizationFrame()
 {
-  delete render_panel_;
-  delete manager_;
-
-  for (int i = 0; i < custom_panels_.size(); i++)
-  {
+  for (int i = custom_panels_.size() - 1; i >= 0; --i)
     delete custom_panels_[i].dock;
-  }
 
   delete panel_factory_;
+  delete render_panel_;
+  delete manager_;
 }
 
 void VisualizationFrame::setApp(QApplication* app)
@@ -477,6 +475,7 @@ void VisualizationFrame::initMenus()
 
   QAction* file_menu_quit_action =
       file_menu_->addAction("&Quit", this, SLOT(close()), QKeySequence("Ctrl+Q"));
+  file_menu_quit_action->setObjectName("actQuit");
   this->addAction(file_menu_quit_action);
 
   view_menu_ = menuBar()->addMenu("&Panels");
@@ -532,7 +531,7 @@ void VisualizationFrame::initToolbars()
   toolbar_->addWidget(remove_tool_button);
   connect(remove_tool_menu_, SIGNAL(triggered(QAction*)), this, SLOT(onToolbarRemoveTool(QAction*)));
 
-  QMenu* button_style_menu = new QMenu();
+  QMenu* button_style_menu = new QMenu(toolbar_);
   QAction* action_tool_button_icon_only = new QAction("Icon only", toolbar_actions_);
   action_tool_button_icon_only->setData(Qt::ToolButtonIconOnly);
   button_style_menu->addAction(action_tool_button_icon_only);
@@ -621,9 +620,9 @@ void VisualizationFrame::onDockPanelVisibilityChange(bool visible)
 void VisualizationFrame::openPreferencesDialog()
 {
   Preferences temp_preferences(*preferences_);
-  PreferencesDialog* dialog = new PreferencesDialog(panel_factory_, &temp_preferences, this);
+  PreferencesDialog dialog(panel_factory_, &temp_preferences, this);
   manager_->stopUpdate();
-  if (dialog->exec() == QDialog::Accepted)
+  if (dialog.exec() == QDialog::Accepted)
   {
     // Apply preferences.
     preferences_ = boost::make_shared<Preferences>(temp_preferences);
@@ -732,7 +731,7 @@ void VisualizationFrame::loadDisplayConfig(const QString& qpath)
   if (!valid_load_path)
   {
     actual_load_path = (fs::path(package_path_) / "default.rviz");
-    if (!(valid_load_path = fs::is_regular_file(actual_load_path)))
+    if (!fs::is_regular_file(actual_load_path))
     {
       ROS_ERROR("Default display config '%s' not found.  RViz will be very empty at first.",
                 actual_load_path.c_str());
@@ -742,11 +741,11 @@ void VisualizationFrame::loadDisplayConfig(const QString& qpath)
   loadDisplayConfigHelper(actual_load_path.string());
 }
 
-bool VisualizationFrame::loadDisplayConfigHelper(const std::string& full_path)
+bool VisualizationFrame::loadDisplayConfigHelper(const std::string& full_path, const bool discard_changes)
 {
   // Check if we have unsaved changes to the current config the same
   // as we do during exit, with the same option to cancel.
-  if (!prepareToExit())
+  if (!discard_changes && !prepareToExit())
   {
     return false;
   }
@@ -754,12 +753,13 @@ bool VisualizationFrame::loadDisplayConfigHelper(const std::string& full_path)
   setWindowModified(false);
   loading_ = true;
 
-  LoadingDialog* dialog = nullptr;
+  std::unique_ptr<LoadingDialog> dialog;
   if (initialized_)
   {
-    dialog = new LoadingDialog(this);
+    dialog.reset(new LoadingDialog(this));
     dialog->show();
-    connect(this, SIGNAL(statusUpdate(const QString&)), dialog, SLOT(showMessage(const QString&)));
+    connect(this, SIGNAL(statusUpdate(const QString&)), dialog.get(), SLOT(showMessage(const QString&)));
+    app_->processEvents(); // make the window correctly appear although running a long-term function
   }
 
   YamlConfigReader reader;
@@ -776,8 +776,6 @@ bool VisualizationFrame::loadDisplayConfigHelper(const std::string& full_path)
 
   last_config_dir_ = fs::path(full_path).parent_path().string();
 
-  delete dialog;
-
   post_load_timer_->start(1000);
 
   return true;
@@ -818,6 +816,7 @@ void VisualizationFrame::setDisplayConfigFile(const std::string& path)
     title = fs::path(path).filename().string() + "[*] - RViz";
   }
   setWindowTitle(QString::fromStdString(title));
+  Q_EMIT displayConfigFileChanged(QString::fromStdString(path));
 }
 
 bool VisualizationFrame::saveDisplayConfig(const QString& path)
@@ -941,11 +940,8 @@ void VisualizationFrame::saveWindowGeometry(Config config)
 void VisualizationFrame::loadPanels(const Config& config)
 {
   // First destroy any existing custom panels.
-  for (int i = 0; i < custom_panels_.size(); i++)
-  {
+  for (int i = custom_panels_.size() - 1; i >= 0; --i)
     delete custom_panels_[i].dock;
-    delete custom_panels_[i].delete_action;
-  }
   custom_panels_.clear();
 
   // Then load the ones in the config.
@@ -1174,6 +1170,19 @@ void VisualizationFrame::addTool(Tool* tool)
   tool_to_action_map_[tool] = action;
 
   remove_tool_menu_->addAction(tool->getName());
+
+  QObject::connect(tool, &Tool::nameChanged, this, &VisualizationFrame::onToolNameChanged);
+}
+
+void VisualizationFrame::onToolNameChanged(const QString& name)
+{
+  // Early return if the tool is not present
+  auto it = tool_to_action_map_.find(qobject_cast<Tool*>(sender()));
+  if (it == tool_to_action_map_.end())
+    return;
+
+  // Change the name of the action
+  it->second->setIconText(name);
 }
 
 void VisualizationFrame::onToolbarActionTriggered(QAction* action)
@@ -1306,6 +1315,23 @@ QWidget* VisualizationFrame::getParentWindow()
   return this;
 }
 
+void VisualizationFrame::onPanelDeleted(QObject* dock)
+{
+  for (int i = 0; i < custom_panels_.size(); ++i)
+  {
+    if (custom_panels_[i].dock == dock)
+    {
+      auto& record = custom_panels_[i];
+      record.delete_action->deleteLater();
+      delete_view_menu_->removeAction(record.delete_action);
+      delete_view_menu_->setDisabled(delete_view_menu_->actions().isEmpty());
+      custom_panels_.removeAt(i);
+      setDisplayConfigModified();
+      return;
+    }
+  }
+}
+
 void VisualizationFrame::onDeletePanel()
 {
   // This should only be called as a SLOT from a QAction in the
@@ -1320,13 +1346,6 @@ void VisualizationFrame::onDeletePanel()
       if (custom_panels_[i].delete_action == action)
       {
         delete custom_panels_[i].dock;
-        custom_panels_.removeAt(i);
-        setDisplayConfigModified();
-        action->deleteLater();
-        if (delete_view_menu_->actions().size() == 1 && delete_view_menu_->actions().first() == action)
-        {
-          delete_view_menu_->setEnabled(false);
-        }
         return;
       }
     }
@@ -1379,6 +1398,7 @@ QDockWidget* VisualizationFrame::addPanelByName(const QString& name,
   record.panel = panel;
   record.name = name;
   record.delete_action = delete_view_menu_->addAction(name, this, SLOT(onDeletePanel()));
+  connect(record.dock, &QObject::destroyed, this, &VisualizationFrame::onPanelDeleted);
   custom_panels_.append(record);
   delete_view_menu_->setEnabled(true);
 
@@ -1394,10 +1414,11 @@ VisualizationFrame::addPane(const QString& name, QWidget* panel, Qt::DockWidgetA
 {
   PanelDockWidget* dock;
   dock = new PanelDockWidget(name);
+  addDockWidget(area, dock);
+
   dock->setContentWidget(panel);
   dock->setFloating(floating);
   dock->setObjectName(name); // QMainWindow::saveState() needs objectName to be set.
-  addDockWidget(area, dock);
 
   // we want to know when that panel becomes visible
   connect(dock, SIGNAL(visibilityChanged(bool)), this, SLOT(onDockPanelVisibilityChange(bool)));
