@@ -35,7 +35,7 @@
 #include <QTimer>
 #include <QWindow>
 
-#include <boost/bind.hpp>
+#include <boost/bind/bind.hpp>
 
 #include <OgreRoot.h>
 #include <OgreSceneManager.h>
@@ -199,6 +199,9 @@ VisualizationManager::VisualizationManager(RenderPanel* render_panel,
 
   selection_manager_ = new SelectionManager(this);
 
+  update_timer_ = new QTimer;
+  connect(update_timer_, SIGNAL(timeout()), this, SLOT(onUpdate()));
+
   private_->threaded_queue_threads_.create_thread(
       boost::bind(&VisualizationManager::threadedQueueThreadFunc, this));
 
@@ -206,18 +209,16 @@ VisualizationManager::VisualizationManager(RenderPanel* render_panel,
 
   ogre_render_queue_clearer_ = new OgreRenderQueueClearer();
   Ogre::Root::getSingletonPtr()->addFrameListener(ogre_render_queue_clearer_);
-
-  update_timer_ = new QTimer;
-  connect(update_timer_, SIGNAL(timeout()), this, SLOT(onUpdate()));
 }
 
 VisualizationManager::~VisualizationManager()
 {
-  delete update_timer_;
-
+  update_timer_->stop();
   shutting_down_ = true;
   private_->threaded_queue_threads_.join_all();
 
+  delete update_timer_;
+
   if (selection_manager_)
   {
     selection_manager_->setSelection(M_Picked());
@@ -564,9 +565,13 @@ void VisualizationManager::handleChar(QKeyEvent* event, RenderPanel* panel)
 
 void VisualizationManager::threadedQueueThreadFunc()
 {
+  ros::WallDuration timeout(0.1);
   while (!shutting_down_)
   {
-    private_->threaded_queue_.callOne(ros::WallDuration(0.1));
+    if (update_timer_->isActive())
+      private_->threaded_queue_.callOne(timeout);
+    else
+      timeout.sleep();
   }
 }
 
