@@ -405,9 +405,8 @@ protected:
   Ogre::Root* ogre_root_;             ///< Ogre Root
   Ogre::SceneManager* scene_manager_; ///< Ogre scene manager associated with this panel
 
-  QTimer* update_timer_; ///< Update timer.  Display::update is called on each display whenever this
-                         /// timer fires
-  ros::Time last_update_ros_time_; ///< Update stopwatch.  Stores how long it's been since the last update
+  QTimer* update_timer_; ///< Display::update is called on each display whenever this timer fires
+  ros::Time last_update_ros_time_; ///< Stores how long it's been since the last update
   ros::WallTime last_update_wall_time_;
 
   volatile bool shutting_down_;
