@@ -4,10 +4,10 @@ from nav_msgs.msg import OccupancyGrid
 import rospy
 import math
 
-topic = 'moving_map'
+topic = "moving_map"
 publisher = rospy.Publisher(topic, OccupancyGrid)
 
-rospy.init_node('map_test')
+rospy.init_node("map_test")
 
 grid = OccupancyGrid()
 
@@ -20,13 +20,13 @@ while not rospy.is_shutdown():
     grid.info.resolution = 1.0
     grid.info.width = 3
     grid.info.height = 3
-    grid.info.origin.position.x = math.cos( t )
-    grid.info.origin.position.y = math.sin( t )
+    grid.info.origin.position.x = math.cos(t)
+    grid.info.origin.position.y = math.sin(t)
     grid.info.origin.orientation.w = 1.0
     grid.data = [0, 20, 40, 60, 80, 100, 120, -10, -100]
 
     # Publish the MarkerArray
-    publisher.publish( grid )
+    publisher.publish(grid)
 
-    rospy.sleep(.05)
-    t += .1
+    rospy.sleep(0.05)
+    t += 0.1
